aboutsummaryrefslogtreecommitdiff
path: root/src/or/relay.c
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2018-02-16 09:54:13 -0500
committerNick Mathewson <nickm@torproject.org>2018-02-16 09:54:13 -0500
commitbd71e0a0c8ccf684c40201f08c456596eac60887 (patch)
tree5b33cdf7ee6ad33cd95499cff7e4e53b56c1559f /src/or/relay.c
parentc67adddacb56f90d77786820f29ca2b4b9f91cae (diff)
parent2bcd264a28e2d6bec1e806e779bf82435c9c7505 (diff)
downloadtor-bd71e0a0c8ccf684c40201f08c456596eac60887.tar.gz
tor-bd71e0a0c8ccf684c40201f08c456596eac60887.zip
Merge branch 'maint-0.3.1' into maint-0.3.2
Diffstat (limited to 'src/or/relay.c')
-rw-r--r--src/or/relay.c14
1 files changed, 12 insertions, 2 deletions
diff --git a/src/or/relay.c b/src/or/relay.c
index 66e10567c1..275746ac93 100644
--- a/src/or/relay.c
+++ b/src/or/relay.c
@@ -2613,22 +2613,32 @@ static time_t last_time_under_memory_pressure = 0;
STATIC int
cell_queues_check_size(void)
{
+ time_t now = time(NULL);
size_t alloc = cell_queues_get_total_allocation();
alloc += buf_get_total_allocation();
alloc += tor_compress_get_total_allocation();
const size_t rend_cache_total = rend_cache_get_total_allocation();
alloc += rend_cache_total;
+ const size_t geoip_client_cache_total =
+ geoip_client_cache_total_allocation();
+ alloc += geoip_client_cache_total;
if (alloc >= get_options()->MaxMemInQueues_low_threshold) {
last_time_under_memory_pressure = approx_time();
if (alloc >= get_options()->MaxMemInQueues) {
/* If we're spending over 20% of the memory limit on hidden service
* descriptors, free them until we're down to 10%.
*/
if (rend_cache_total > get_options()->MaxMemInQueues / 5) {
const size_t bytes_to_remove =
rend_cache_total - (size_t)(get_options()->MaxMemInQueues / 10);
alloc -= hs_cache_handle_oom(time(NULL), bytes_to_remove);
}
+ if (geoip_client_cache_total > get_options()->MaxMemInQueues / 5) {
+ const size_t bytes_to_remove =
+ geoip_client_cache_total -
+ (size_t)(get_options()->MaxMemInQueues / 10);
+ alloc -= geoip_client_cache_handle_oom(now, bytes_to_remove);
+ }
circuits_handle_oom(alloc);
return 1;
}
@@ -2613,22 +2613,32 @@ static time_t last_time_under_memory_pressure = 0;
if (alloc >= get_options()->MaxMemInQueues) {
/* If we're spending over 20% of the memory limit on hidden service
- * descriptors, free them until we're down to 10%.
- */
+ * descriptors, free them until we're down to 10%. Do the same for geoip
+ * client cache. */
if (rend_cache_total > get_options()->MaxMemInQueues / 5) {
const size_t bytes_to_remove =